@@ -272,7 +272,7 @@ class ExtendedMinimizer(object):
             status = self.minimizer.minimize(minimizer_type, minimizer_algo)
         
         if status not in [0, 1]:
-            print('ExtenedMinimizer::robust_minimize("{}") fit failed with status {}'.format(self.name, status))
+            print('ExtendedMinimizer::robust_minimize("{}") fit failed with status {}'.format(self.name, status))
         
         self.minimizer.setStrategy(self.config['default_strategy'])
         
@@ -286,6 +286,7 @@ class ExtendedMinimizer(object):
         elif (val > par.getMax()):
             print('ExtendedMinimizer::use_limits("{}") {} = {} limited by maximum at {}'.format(
                    self.name, par.GetName(), val, par.getMax()))
+            return par.getMax()
         else:
             return val
     
@@ -400,7 +401,7 @@ class ExtendedMinimizer(object):
             
             # subtract off the difference in the new and damped correction
             val_guess -= corr
-            guess_to_corr[val_pre] = corr
+            guess_to_corr[val_pre] = corr          
             val_guess = self.use_limits(par, val_guess)
             rel_precision = precision*abs(val_guess-val_mle)
             delta = val_guess - val_pre
