@@ -200,12 +200,12 @@ class NuisanceParameterPull(object):
                 'type'        : int,
                 'default'     : 0
             },
-            'no_cache'  : {
+            'cache'  : {
                 'abbr'        : None,
                 'description' : 'Cache existing result', 
                 'required'    : False,
                 'type'        : bool,
-                'default'     : False
+                'default'     : True
             },
             'exclude'  : {
                 'abbr'        : None,
@@ -290,11 +290,11 @@ class NuisanceParameterPull(object):
                    precision:float=0.001, eps:float=1.0, strategy:int=0, 
                    num_cpu:int=1, offset:int=1, optimize:int=2, eigen:bool=False,
                    fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
-                   max_iters:int=-1, outdir:str='output', no_cache=False, **kwargs):
+                   max_iters:int=-1, outdir:str='output', cache=True, **kwargs):
         outname_root = os.path.join(outdir, nuis_name + '.root')
         outname_json = os.path.join(outdir, nuis_name + '.json')
         #checkpointing:
-        if (os.path.exists(outname_root) and os.path.exists(outname_json)) and (not no_cache):
+        if (os.path.exists(outname_root) and os.path.exists(outname_json)) and cache:
             print('INFO: Jobs already finished for the NP: {}. Skipping.'.format(nuis_name))
             return None
         start_time = time.time()
@@ -473,7 +473,8 @@ class NuisanceParameterPull(object):
                  data='combData', poi='', snapshot='nominalNuis', outdir='output', profile="",
                  fix='', minimizer_type='Minuit2', minimizer_algo='Migrad', num_cpu=1, binned=1,
                  precision=0.001, eps=1.0, log_level='INFO', eigen=0, strategy=0, fix_cache=1, fix_multi=1,
-                 offset=1, optimize=2, parameter="", max_calls=-1, max_iters=-1, parallel=0, no_cache=False, **kwargs):
+                 offset=1, optimize=2, parameter="", max_calls=-1, max_iters=-1, parallel=0, cache=True, 
+                 exclude='', **kwargs):
         
         start_time = time.time()
         
@@ -516,7 +517,8 @@ class NuisanceParameterPull(object):
                 self._run_pulls(input_file, workspace, model_config, data, snapshot,
                                 nuis_name, poi, fix, profile, binned, minimizer_type, 
                                 minimizer_algo, precision, eps, strategy, num_cpu, offset, 
-                                optimize, eigen, fix_cache, fix_multi, max_calls, max_iters, outdir)
+                                optimize, eigen, fix_cache, fix_multi, max_calls, max_iters,
+                                outdir, cache)
         end_time = time.time()
         print('INFO: All jobs have finished. Total Time taken: {:.3f} s'.format(end_time-start_time))
         
